@@ -33,6 +33,19 @@ def compile(model, input_shape=[], library="", model_label="", asynchronous=Fals
     return core.compile(model, input_shape, library, model_label, asynchronous)
 
 
+def upload_data(data, name=""):
+    """Use this to upload your data.
+
+        :param data: Raw data to upload.
+        :type data: (numpy, Pytorch Tensor, Mxnet NDArray, Tensorflow tf.Data)
+        :param name: Name to be given to data.
+        :type name: str, optional
+
+        :return: data as id.
+    """
+    return core.upload_data(data, name)
+
+
 def predict(model, data, asynchronous=False, callback=None, **kwargs):
     """Perform a predict using a model. Default behaviour is synchronous.
 
@@ -48,7 +61,7 @@ def predict(model, data, asynchronous=False, callback=None, **kwargs):
     return core.predict(model, data, asynchronous, callback, **kwargs)
 
 
-def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.SGD(), loss=loss.SparseCrossEntropyLoss, asynchronous=False, callback=None, **kwargs):
+def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.SGD(), loss=loss.SparseCrossEntropyLoss, trained_model_name="", asynchronous=False, callback=None, **kwargs):
     """Perform a train using a model. Default behaviour is synchronous.
 
         :param model: Model used to predict
@@ -70,7 +83,7 @@ def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.S
         :param callback: runs a callback function on results (asynchronous)
         :type callback: function
     """
-    return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, asynchronous, callback, **kwargs)
+    return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, trained_model_name, asynchronous, callback, **kwargs)
 
 
 def export(model, path="."):
